
dag-cbor: A Python implementation of the DAG-CBOR codec
=======================================================

This is a fully compliant Python implementation of the `DAG-CBOR codec <https://ipld.io/specs/codecs/dag-cbor/spec/>`_, a subset of the `Concise Binary Object Representation (CBOR) <https://cbor.io/>`_ supporting the `IPLD Data Model <https://ipld.io/docs/data-model/>`_ and enforcing a unique (strict) encoded representation of items.

GitHub repo: https://github.com/hashberg-io/dag-cbor


.. toctree::
    :maxdepth: 3
    :caption: Contents

    getting-started
    encoding
    decoding
    random

.. include:: api-toc.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
